"""
Python module generated from Java source file org.bukkit.material.ExtendedRails

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class ExtendedRails(Rails):
    """
    This is the superclass for the DetectorRail and PoweredRail
    classes

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def isCurve(self) -> bool:
        ...


    def setDirection(self, face: "BlockFace", isOnSlope: bool) -> None:
        ...


    def clone(self) -> "ExtendedRails":
        ...



"""
Python module generated from Java source file org.bukkit.block.Comparator

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import *
from typing import Any, Callable, Iterable, Tuple


class Comparator(TileState):
    """
    Represents a captured state of an on / off comparator.
    """





"""
Python module generated from Java source file org.bukkit.event.player.PlayerLocaleChangeEvent

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Player
from org.bukkit.event import HandlerList
from org.bukkit.event.player import *
from typing import Any, Callable, Iterable, Tuple


class PlayerLocaleChangeEvent(PlayerEvent):
    """
    Called when a player changes their locale in the client settings.
    """

    def __init__(self, who: "Player", locale: str):
        ...


    def getLocale(self) -> str:
        """
        Returns
        - the player's new locale

        See
        - Player.getLocale()
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.HangingMoss

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import MinecraftExperimental
from org.bukkit.block.data import BlockData
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class HangingMoss(BlockData):
    """
    'tip' indicates whether this block is a tip.
    """

    def isTip(self) -> bool:
        """
        Gets the value of the 'tip' property.

        Returns
        - the 'tip' value
        """
        ...


    def setTip(self, tip: bool) -> None:
        """
        Sets the value of the 'tip' property.

        Arguments
        - tip: the new 'tip' value
        """
        ...



"""
Python module generated from Java source file org.bukkit.material.EnderChest

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Material
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class EnderChest(DirectionalContainer):
    """
    Represents an ender chest

    Deprecated
    - all usage of MaterialData is deprecated and subject to removal.
    Use org.bukkit.block.data.BlockData.
    """

    def __init__(self):
        ...


    def __init__(self, direction: "BlockFace"):
        """
        Instantiate an ender chest facing in a particular direction.

        Arguments
        - direction: the direction the ender chest's lid opens towards
        """
        ...


    def __init__(self, type: "Material"):
        ...


    def __init__(self, type: "Material", data: int):
        """
        Arguments
        - type: the type
        - data: the raw data value

        Deprecated
        - Magic value
        """
        ...


    def clone(self) -> "EnderChest":
        ...



"""
Python module generated from Java source file org.bukkit.block.data.type.Vault

Java source file obtained from artifact spigot-api version 1.21.3-R0.1-20241203.162251-46

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from enum import Enum
from org.bukkit.block.data import Directional
from org.bukkit.block.data.type import *
from typing import Any, Callable, Iterable, Tuple


class Vault(Directional):
    """
    'vault_state' indicates the current operational phase of the vault block.
    
    'ominous' indicates if the block has ominous effects.
    """

    def getVaultState(self) -> "State":
        """
        Gets the value of the 'vault_state' property.

        Returns
        - the 'vault_state' value
        """
        ...


    def getTrialSpawnerState(self) -> "State":
        """
        Gets the value of the 'vault_state' property.

        Returns
        - the 'vault_state' value

        Deprecated
        - see .getVaultState()
        """
        ...


    def setVaultState(self, state: "State") -> None:
        """
        Sets the value of the 'vault_state' property.

        Arguments
        - state: the new 'vault_state' value
        """
        ...


    def setTrialSpawnerState(self, state: "State") -> None:
        """
        Sets the value of the 'vault_state' property.

        Arguments
        - state: the new 'vault_state' value

        Deprecated
        - see .setVaultState(State)
        """
        ...


    def isOminous(self) -> bool:
        """
        Gets the value of the 'ominous' property.

        Returns
        - the 'ominous' value
        """
        ...


    def setOminous(self, ominous: bool) -> None:
        """
        Sets the value of the 'ominous' property.

        Arguments
        - ominous: the new 'ominous' value
        """
        ...


    class State(Enum):

        INACTIVE = 0
        ACTIVE = 1
        UNLOCKING = 2
        EJECTING = 3
